Function diem_retrier::retry [−][src]
pub fn retry<I, O, T, E>(iterable: I, operation: O) -> Result<T, E> where
I: IntoIterator<Item = Duration>,
O: FnMut() -> Result<T, E>, Expand description
Given an operation retries it successfully sleeping everytime it fails If the operation succeeds before the iterator runs out, it returns success